##  Create an API Key In the Walkme Admin Center
**Note**
You need WalkMe admin privileges to create the API key.
  1. Navigate to WalkMe Admin Center → API Keys.
  2. Click Create New Key in the top-right. This opens a side panel on the right.
  3. In the side panel, give an appropriate name for the integration and toggle the Discovery Apps API permission on with Read rights.
![Creating API Key In WalkMe Admin Center](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274bff507a441014b97bff0f9cfa5522_LowRes.png)
Creating API Key In WalkMe Admin Center
  4. Click Create. Do not close the side panel until the key is generated.
  5. Copy and store the Client ID and Client Secret. These are required when configuring the WalkMe integration in SAP LeanIX.


**Note**
Make sure to copy and store the client secret value when it is revealed. Once you close the key details panel, the value is masked and cannot be recovered.
